@@ -1,10 +1,14 @@
 import { Fork } from "../types";
-import { LogicalOperators } from "./core-operators";
+import es2020OpsDef from "./operators/es2020";
 import es2019Def from "./es2019";
 import typesPlugin from "../lib/types";
 import sharedPlugin from "../lib/shared";
 
 export default function (fork: Fork) {
+  // The es2020OpsDef plugin comes before es2019Def so LogicalOperators will be
+  // appropriately augmented before first used.
+  fork.use(es2020OpsDef);
+
   fork.use(es2019Def);
 
   const types = fork.use(typesPlugin);
@@ -25,19 +29,29 @@ export default function (fork: Fork) {
     .field("exported", or(def("Identifier"), null));
 
   // Optional chaining
-  def("OptionalMemberExpression")
-    .bases("MemberExpression")
-    .build("object", "property", "computed", "optional")
-    .field("optional", Boolean, defaults["true"])
+  def("ChainElement")
+    .bases("Node")
+    .field("optional", Boolean, defaults["false"]);
+
+  def("CallExpression")
+    .bases("Expression", "ChainElement");
+
+  def("MemberExpression")
+    .bases("Expression", "ChainElement");
+
+  def("ChainExpression")
+    .bases("Expression")
+    .build("expression")
+    .field("expression", def("ChainElement"));
 
   def("OptionalCallExpression")
     .bases("CallExpression")
     .build("callee", "arguments", "optional")
-    .field("optional", Boolean, defaults["true"])
+    .field("optional", Boolean, defaults["true"]);
 
-  // Nullish coalescing
-  const LogicalOperator = or(...LogicalOperators, "??");
-
-  def("LogicalExpression")
-    .field("operator", LogicalOperator)
+  // Deprecated optional chaining type, doesn't work with babelParser@7.11.0 or newer
+  def("OptionalMemberExpression")
+    .bases("MemberExpression")
+    .build("object", "property", "computed", "optional")
+    .field("optional", Boolean, defaults["true"]);
 };
