@@ -30,7 +30,7 @@ import typesPlugin from "../lib/types";
 import esprimaDef from "../def/esprima";
 import coreDef from "../def/core";
 import es6Def from "../def/es6";
-import es2020Def from "../def/es2020";
+import esProposalsDef from "../def/es-proposals";
 import babelDef from "../def/babel";
 
 const {
@@ -229,7 +229,7 @@ describe("shallow and deep checks", function() {
 
   it("should fail when expected", function() {
     // Not an Expression.
-    assert.ok(!n.Expression.check(decl));
+    assert.strictEqual(n.Expression.check(decl), false);
 
     // This makes decl cease to conform to n.VariableDeclaration.
     decl.declarations.push(b.literal("bar") as $InvalidType);
@@ -437,7 +437,7 @@ describe("types.eachField", function() {
     try {
       check({ type: "asdf" }, ["type"]);
       throw new Error("should have thrown");
-    } catch (e) {
+    } catch (e: any) {
       assert.strictEqual(
         e.message,
         'did not recognize object of type "asdf"'
@@ -571,7 +571,7 @@ describe("types.visit", function() {
       visitMemberExpression: function(path) {
         try {
           this.traverse(path);
-        } catch (err) {
+        } catch (err: any) {
           assert.ok(err instanceof this.AbortRequest);
           err.cancel();
         }
@@ -1209,6 +1209,31 @@ describe("scope methods", function () {
     assert.deepEqual(names, ["x", "xyDefault", "xyNamespace", "z"]);
   });
 
+  describe("getBindings should work with destructuring operations", function() {
+    const code = `
+function aFunction(arg1, { arg2 }) {
+  const { arg3, nested: { something: arg4 } } = arg1;
+  const [arg5] = arg1;
+  return 0;
+}`;
+    for (const { parser, parserName } of [
+      { parser: parse, parserName: "esprima" },
+      { parser: babylonParse, parserName: "babel" }
+    ]) {
+      it(`produces the correct bindings with ${parserName} parser`, function() {
+        const ast = parser(code);
+
+        visit(ast, {
+          visitReturnStatement: function(path) {
+            const names = Object.keys(path.scope.getBindings()).sort();
+            assert.deepEqual(names, ["arg1", "arg2", "arg3", "arg4", "arg5"]);
+            return false;
+          }
+        })
+      });
+    }
+  });
+
   (nodeMajorVersion >= 6 ? it : xit)
   ("should work for ES6 syntax (espree)", function() {
     var names;
@@ -1233,6 +1258,32 @@ describe("scope methods", function () {
     });
   });
 
+(nodeMajorVersion >= 6 ? it : xit)
+  ("should work with classes for ES6 syntax (espree)", function() {
+    var names;
+
+    var ast = espree.parse([
+      "var zap;",
+      "export default class {",
+      "    render () {",
+      "        var innerFn = function(zip) {};",
+      "        return innerFn(zom);",
+      "    }",
+      "};"
+    ].join("\n"), {
+      sourceType: "module",
+      ecmaVersion: 2020,
+    });
+
+    visit(ast, {
+      visitCallExpression: function(path) {
+        names = Object.keys(path.scope.lookup("zap").getBindings()).sort();
+        assert.deepEqual(names, ["zap"]);
+        this.traverse(path);
+      }
+    });
+  });
+
   it("should inject temporary into current scope", function() {
     var ast = parse(scope.join("\n"));
     var bindings;
@@ -1444,7 +1495,7 @@ describe("array and object pattern scope", function() {
     var types = fork([
       coreDef,
       es6Def,
-      es2020Def,
+      esProposalsDef,
     ]);
     var b = types.builders;
 
@@ -1583,7 +1634,7 @@ describe("types.visit", function() {
 
       assert.ok(false, "should have thrown an exception");
 
-    } catch (err) {
+    } catch (err: any) {
       assert.strictEqual(
         err.message,
         "Must either call this.traverse or return false in visitIdentifier"
@@ -2280,15 +2331,16 @@ describe("RegExpLiteral nodes", function() {
 
   it("should typecheck with explicit .regex field", function() {
     var stringLiteral = b.literal("asdf");
-    assert.strictEqual(stringLiteral.regex, null);
+    assert.strictEqual(hasOwn.call(stringLiteral, "regex"), false);
     n.Literal.assert(stringLiteral, true);
 
-    var regExpLiteral: any = b.literal(/a.b/gi);
-    assert.strictEqual(regExpLiteral.regex.pattern, "a.b");
-    assert.strictEqual(regExpLiteral.regex.flags, "ig");
+    const regExpLiteral = b.regExpLiteral("a.b", "gi");
+    const regex = rawTypes.getFieldValue(regExpLiteral, "regex");
+    assert.strictEqual(regex.pattern, "a.b");
+    assert.strictEqual(regex.flags, "gi");
     n.Literal.assert(regExpLiteral, true);
 
-    regExpLiteral.regex.pattern = 1234;
+    regex.pattern = 1234;
     assert.strictEqual(n.Literal.check(regExpLiteral, true), false);
   });
 });
@@ -2415,49 +2467,127 @@ describe("MemberExpression", function() {
   });
 });
 
-describe("Optional Chaining", function() {
-  describe('OptionalMemberExpression', function() {
-    it("should set optional to true by default", function(){
-      var optionalMemberExpression = b.optionalMemberExpression(
+describe("Optional Chaining", function () {
+  describe("ChainExpression", function () {
+    it("should set expression.optional in CallExpression to false by default", function () {
+      const chainExpression = b.chainExpression(
+        b.callExpression(
+          b.identifier("call"),
+          [],
+        ),
+      );
+
+      n.CallExpression.assert(chainExpression.expression);
+      n.ChainElement.assert(chainExpression.expression);
+
+      assert.strictEqual(chainExpression.expression.optional, false);
+    });
+
+    it("can set expression.optional in CallExpression to true", function () {
+      const chainExpression = b.chainExpression(
+        b.callExpression.from({
+          callee: b.identifier("fn"),
+          arguments: [],
+          optional: true,
+        }),
+      );
+
+      n.CallExpression.assert(chainExpression.expression);
+      n.ChainElement.assert(chainExpression.expression);
+
+      assert.strictEqual(chainExpression.expression.optional, true);
+    });
+
+    it("should set expression.optional in MemberExpression to false by default", function () {
+      const chainExpression = b.chainExpression(
+        b.memberExpression(
+          b.identifier("a"),
+          b.identifier("b"),
+          false,
+        ),
+      );
+
+      n.MemberExpression.assert(chainExpression.expression);
+      n.ChainElement.assert(chainExpression.expression);
+
+      assert.strictEqual(chainExpression.expression.optional, false);
+    });
+
+    it("can set expression.optional in MemberExpression to true", function () {
+      const chainExpression = b.chainExpression(
+        b.memberExpression.from({
+          object: b.identifier("a"),
+          property: b.identifier("b"),
+          computed: false,
+          optional: true,
+        }),
+      );
+
+      n.MemberExpression.assert(chainExpression.expression);
+      n.ChainElement.assert(chainExpression.expression);
+
+      assert.strictEqual(chainExpression.expression.optional, true);
+    });
+  });
+
+  describe('OptionalCallExpression', function() {
+    it("should set optional to true by default", function () {
+      const optionalCallExpression = b.optionalCallExpression(
+        b.identifier('foo'),
+        []
+      );
+
+      n.OptionalCallExpression.assert(optionalCallExpression);
+      n.CallExpression.assert(optionalCallExpression);
+      n.ChainElement.assert(optionalCallExpression);
+
+      assert.strictEqual(optionalCallExpression.optional, true);
+    });
+
+    it("should allow optional to be false", function () {
+      const optionalCallExpression = b.optionalCallExpression(
+        b.identifier('foo'),
+        [],
+        false
+      );
+
+      n.OptionalCallExpression.assert(optionalCallExpression);
+      n.CallExpression.assert(optionalCallExpression);
+      n.ChainElement.assert(optionalCallExpression);
+
+      assert.strictEqual(optionalCallExpression.optional, false);
+    });
+  });
+
+  describe('OptionalMemberExpression', function () {
+    it("should set optional to true by default", function () {
+      const optionalMemberExpression = b.optionalMemberExpression(
         b.identifier('foo'),
         b.identifier('bar')
       );
 
+      n.OptionalMemberExpression.assert(optionalMemberExpression);
+      n.MemberExpression.assert(optionalMemberExpression);
+      n.ChainElement.assert(optionalMemberExpression);
+
       assert.strictEqual(optionalMemberExpression.optional, true);
     });
 
-    it("should allow optional to be false", function(){
-      var optionalMemberExpression = b.optionalMemberExpression(
+    it("should allow optional to be false", function () {
+      const optionalMemberExpression = b.optionalMemberExpression(
         b.identifier('foo'),
         b.identifier('bar'),
         true,
         false
       );
 
+      n.OptionalMemberExpression.assert(optionalMemberExpression);
+      n.MemberExpression.assert(optionalMemberExpression);
+      n.ChainElement.assert(optionalMemberExpression);
+
       assert.strictEqual(optionalMemberExpression.optional, false);
     });
   });
-
-  describe('OptionalCallExpression', function() {
-    it("should set optional to true by default", function(){
-      var optionalCallExpression = b.optionalCallExpression(
-        b.identifier('foo'),
-        []
-      );
-
-      assert.strictEqual(optionalCallExpression.optional, true);
-    });
-
-    it("should allow optional to be false", function(){
-      var optionalCallExpression = b.optionalCallExpression(
-        b.identifier('foo'),
-        [],
-        false
-      );
-
-      assert.strictEqual(optionalCallExpression.optional, false);
-    });
-  });
 });
 
 describe('Nullish Coalescing Operator', function() {
@@ -2487,7 +2617,7 @@ describe('Dynamic import', () => {
     visit,
     namedTypes: n,
     builders: b,
-  } = fork([ es2020Def ]);
+  } = fork([ esProposalsDef ]);
 
   it('should work with expression values', () => {
     const importExpression =  b.importExpression(
