@@ -4,18 +4,17 @@ set -ex
 
 cd $(dirname $0)/data
 
-BAB_TAG=v$(node -p 'require("babylon/package.json").version')
+BAB_TAG=v$(node -p 'require("@babel/parser/package.json").version')
 
-if [ ! -d babylon ]
+if [ ! -d babel-parser ]
 then
     git clone --branch "$BAB_TAG" --depth 1 \
         https://github.com/babel/babel.git
-    mv babel/packages/babylon .
+    mv babel/packages/babel-parser .
     rm -rf babel
 fi
 
-# Hard-code this for now.
-TS_TAG=v2.7.2
+TS_TAG=v$(node -p 'require("typescript/package.json").version')
 
 if [ ! -d typescript-compiler ]
 then
@@ -27,4 +26,6 @@ fi
 
 cd .. # back to the ast-types/test/ directory
 
+# Run Mocha on the generated .js code, rather than the .ts source code, so
+# that we're testing the same kind of output that we're shipping to npm.
 exec mocha --reporter spec --full-trace $@ run.js
